package com.miaxis.film.domain;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.miaxis.common.annotation.Excel;
import com.miaxis.common.core.domain.BaseBusinessEntity;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.util.Date;
/**
 * 电影订单对象 film_order
 *
 * @author miaxis
 * @date 2021-05-07
 */
@Data
@TableName("film_order")
@ApiModel(value = "FilmOrder", description = "电影订单对象 film_order")
public class FilmOrder extends BaseBusinessEntity{
    private static final long serialVersionUID = 1L;

    /** id */
    @TableId(value = "id")
    @ApiModelProperty(value = "id")
    private Long id;

    /** 商户订单号 */
    @Excel(name = "商户订单号")
    @TableField("out_trade_no")
    @ApiModelProperty(value = "商户订单号")
    private String outTradeNo;

    /** 微信支付系统生成的订单号 */
    @Excel(name = "微信支付系统生成的订单号")
    @TableField("transaction_id")
    @ApiModelProperty(value = "微信支付系统生成的订单号")
    private String transactionId;

    /** 交易类型，枚举值 */
    @Excel(name = "交易类型，枚举值")
    @TableField("trade_type")
    @ApiModelProperty(value = "交易类型，枚举值")
    private String tradeType;

    /** 交易状态，枚举值：
SUCCESS：支付成功
REFUND：转入退款
NOTPAY：未支付
CLOSED：已关闭
REVOKED：已撤销（付款码支付）
USERPAYING：用户支付中（付款码支付）
PAYERROR：支付失败(其他原因，如银行返回失败)
ACCEPT：已接收，等待扣款 */
    @TableField("trade_state")
    @ApiModelProperty(value = "交易状态，枚举值： SUCCESS：支付成功 REFUND：转入退款 NOTPAY：" +
            "未支付 CLOSED：已关闭 REVOKED：已撤销（付款码支付） " +
            "USERPAYING：用户支付中（付款码支付） PAYERROR：支付失败(其他原因，如银行返回失败) ACCEPT：已接收，等待扣款")
    private String tradeState;
    /** 交易状态描述 */
    @Excel(name = "交易状态描述")
    @TableField("trade_state_desc")
    @ApiModelProperty(value = "交易状态描述")
    private String tradeStateDesc;

    /** 银行类型 */
    @Excel(name = "银行类型")
    @TableField("bank_type")
    @ApiModelProperty(value = "银行类型")
    private String bankType;

    /** 附加数据 */
    @Excel(name = "附加数据")
    @TableField("attach")
    @ApiModelProperty(value = "附加数据")
    private String attach;

    /** 支付完成时间 */
    @JsonFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "支付完成时间", width = 30, dateFormat = "yyyy-MM-dd")
    @TableField("success_time")
    @ApiModelProperty(value = "支付完成时间")
    private Date successTime;

    /** 用户在直连商户appid下的唯一标识 */
    @Excel(name = "用户在直连商户appid下的唯一标识")
    @TableField("openid")
    @ApiModelProperty(value = "用户在直连商户appid下的唯一标识")
    private String openid;

    /** 商品名称 */
    @Excel(name = "商品名称")
    @TableField("goods_name")
    @ApiModelProperty(value = "商品名称")
    private String goodsName;

    /** 订单总金额，单位为分。 */
    @Excel(name = "订单总金额，单位为分。")
    @TableField("total")
    @ApiModelProperty(value = "订单总金额，单位为分。")
    private Integer total;

    /** 用户支付金额，单位为分。 */
    @Excel(name = "用户支付金额，单位为分。")
    @TableField("payer_total")
    @ApiModelProperty(value = "用户支付金额，单位为分。")
    private Integer payerTotal;

    /** CNY：人民币，境内商户号仅支持人民币。 */
    @Excel(name = "CNY：人民币，境内商户号仅支持人民币。")
    @TableField("currency")
    @ApiModelProperty(value = "CNY：人民币，境内商户号仅支持人民币。")
    private String currency;

    /** 用户支付币种 */
    @Excel(name = "用户支付币种")
    @TableField("payer_currency")
    @ApiModelProperty(value = "用户支付币种")
    private String payerCurrency;

    /** 商户端设备号 */
    @Excel(name = "商户端设备号")
    @TableField("device_id")
    @ApiModelProperty(value = "商户端设备号")
    private String deviceId;

    /** 商户端设备号 */
    @Excel(name = "排期的showId,由影院接口得来")
    @TableField("show_id")
    @ApiModelProperty(value = "排期的showId,由影院接口得来")
    private String showId;

    /** 用户所选的座位，例：1排1座,1排2座 以英文的逗号 “ , “隔开。 如果座位是情侣座，请传入 ： 1排1座(情侣座),1排2座(情侣座) */
    @Excel(name = "用户所选的座位，例：1排1座,1排2座 以英文的逗号 “ , “隔开。 如果座位是情侣座，请传入 ： 1排1座(情侣座),1排2座(情侣座)")
    @TableField("seat")
    @ApiModelProperty(value = "用户所选的座位，例：1排1座,1排2座 以英文的逗号 “ , “隔开。 如果座位是情侣座，请传入 ： 1排1座(情侣座),1排2座(情侣座)")
    private String seat;

    /** 预留的手机号 */
    @Excel(name = "预留的手机号")
    @TableField("reserved_phone")
    @ApiModelProperty(value = "预留的手机号")
    private String reservedPhone;

    /** 是否允许调座，1-允许，0-不允许 */
    @Excel(name = "是否允许调座，1-允许，0-不允许")
    @TableField("accept_change_seat")
    @ApiModelProperty(value = "是否允许调座，1-允许，0-不允许")
    private Integer acceptChangeSeat;

    /** 座位接口的seatId字段， 如果有多个，则以竖线分割 */
    @Excel(name = "座位接口的seatId字段， 如果有多个，则以竖线分割")
    @TableField("seat_id")
    @ApiModelProperty(value = "座位接口的seatId字段， 如果有多个，则以竖线分割")
    private String seatId;

    /** 座位接口的seatNo字段，如果有多个，则以竖线分割 */
    @Excel(name = "座位接口的seatNo字段，如果有多个，则以竖线分割")
    @TableField("seat_no")
    @ApiModelProperty(value = "座位接口的seatNo字段，如果有多个，则以竖线分割")
    private String seatNo;

    /** 订单状态，枚举值:
ORDER_CLOSE  关闭
ORDER_FINISH  订单正常处理完毕
WAIT_TICKET 订单竞价结束，正在等待出票
TICKET_SUCCESS 订单出票成功
TICKET_SYNC 取票码出现意外情况，需要修改时 */
    @TableField("order_state")
    @ApiModelProperty(value = "订单状态，枚举值: ORDER_CLOSE  关闭 ORDER_FINISH  订单正常处理完毕" +
            " WAIT_TICKET 订单竞价结束，正在等待出票 TICKET_SUCCESS 订单出票成功 TICKET_SYNC 取票码出现意外情况，需要修改时")
    private String orderState;

    /** api下单成本价 */
    @Excel(name = "api下单成本价")
    @TableField("order_price")
    @ApiModelProperty(value = "api下单成本价")
    private Integer orderPrice;

    /** 订单关闭原因 */
    @Excel(name = "订单关闭原因")
    @TableField("close_cause")
    @ApiModelProperty(value = "订单关闭原因")
    private String closeCause;

    /** 实际出票位置 */
    @Excel(name = "实际出票位置")
    @TableField("real_seat")
    @ApiModelProperty(value = "实际出票位置")
    private String realSeat;

    /** 取票字符串 */
    @Excel(name = "取票字符串")
    @TableField("ticket_code")
    @ApiModelProperty(value = "取票字符串")
    private String ticketCode;

    /** 取票码原始截图 */
    @Excel(name = "取票码原始截图")
    @TableField("ticket_image")
    @ApiModelProperty(value = "取票码原始截图")
    private String ticketImage;


}
